--- loncom/interface/portfolio.pm 2012/12/17 06:29:02 1.239
+++ loncom/interface/portfolio.pm 2013/04/11 14:59:49 1.240
@@ -1,7 +1,7 @@
# The LearningOnline Network
# portfolio browser
#
-# $Id: portfolio.pm,v 1.239 2012/12/17 06:29:02 raeburn Exp $
+# $Id: portfolio.pm,v 1.240 2013/04/11 14:59:49 bisitz Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -63,7 +63,7 @@ sub group_form_data {
return $output;
}
# receives a file name and path stub from username/userfiles/portfolio/
# returns an anchor tag consisting encoding filename and currentpath
sub make_anchor {
my ($url, $anchor_fields, $inner_text) = @_;
@@ -809,7 +809,7 @@ sub rename_confirmed {
return;
}
if ($filenewname ne $env{'form.filenewname'}) {
- $r->print(&mt("The new file name was changed from:
[_1] to [_2]",
+ $r->print(&mt("The new filename was changed from:
[_1] to [_2]",
''.&display_file('',$env{'form.filenewname'}).'',
''.&display_file('',$filenewname).''));
@@ -63,7 +63,7 @@ sub group_form_data {
return $output;
}
-# receives a file name and path stub from username/userfiles/portfolio/
+# receives a filename and path stub from username/userfiles/portfolio/
# returns an anchor tag consisting encoding filename and currentpath
sub make_anchor {
}